@@ -3,9 +3,8 @@ use strict;
 use warnings;
 use CairoX::Sweet::Standard;
 
-our $VERSION = '0.0102'; # VERSION
+our $VERSION = '0.0103'; # VERSION
 # PODNAME: CairoX::Sweet::Color
-# ABSTRACT:
 
 class CairoX::Sweet::Color using Moose {
 
@@ -38,11 +37,11 @@ __END__
 
 =head1 NAME
 
-CairoX::Sweet::Color - class CairoX::Sweet::Color using Moose {
+CairoX::Sweet::Color
 
 =head1 VERSION
 
-Version 0.0102, released 2015-01-11.
+Version 0.0103, released 2015-01-11.
 
 =head1 SOURCE
 
