@@ -3,9 +3,8 @@ use strict;
 use warnings;
 use CairoX::Sweet::Standard;
 
-our $VERSION = '0.0102'; # VERSION
+our $VERSION = '0.0103'; # VERSION
 # PODNAME: CairoX::Sweet::Core::CurveTo
-# ABSTRACT:
 
 class CairoX::Sweet::Core::CurveTo with CairoX::Sweet::Role::PathCommand using Moose {
 
@@ -58,11 +57,11 @@ __END__
 
 =head1 NAME
 
-CairoX::Sweet::Core::CurveTo - class CairoX::Sweet::Core::CurveTo with CairoX::Sweet::Role::PathCommand using Moose {
+CairoX::Sweet::Core::CurveTo
 
 =head1 VERSION
 
-Version 0.0102, released 2015-01-11.
+Version 0.0103, released 2015-01-11.
 
 =head1 SOURCE
 
