@@ -3,9 +3,8 @@ use strict;
 use warnings;
 use CairoX::Sweet::Standard;
 
-our $VERSION = '0.0102'; # VERSION
+our $VERSION = '0.0103'; # VERSION
 # PODNAME: CairoX::Sweet::Core::MoveTo
-# ABSTRACT:
 
 class CairoX::Sweet::Core::MoveTo with CairoX::Sweet::Role::PathCommand using Moose {
 
@@ -48,11 +47,11 @@ __END__
 
 =head1 NAME
 
-CairoX::Sweet::Core::MoveTo - class CairoX::Sweet::Core::MoveTo with CairoX::Sweet::Role::PathCommand using Moose {
+CairoX::Sweet::Core::MoveTo
 
 =head1 VERSION
 
-Version 0.0102, released 2015-01-11.
+Version 0.0103, released 2015-01-11.
 
 =head1 SOURCE
 
