@@ -3,9 +3,8 @@ use strict;
 use warnings;
 use CairoX::Sweet::Standard;
 
-our $VERSION = '0.0102'; # VERSION
+our $VERSION = '0.0103'; # VERSION
 # PODNAME: CairoX::Sweet::Core::Point
-# ABSTRACT:
 
 class CairoX::Sweet::Core::Point using Moose {
 
@@ -37,11 +36,11 @@ __END__
 
 =head1 NAME
 
-CairoX::Sweet::Core::Point - class CairoX::Sweet::Core::Point using Moose {
+CairoX::Sweet::Core::Point
 
 =head1 VERSION
 
-Version 0.0102, released 2015-01-11.
+Version 0.0103, released 2015-01-11.
 
 =head1 SOURCE
 
