@@ -3,9 +3,8 @@ use warnings;
 
 use Moops;
 
-our $VERSION = '0.0102'; # VERSION
+our $VERSION = '0.0103'; # VERSION
 # PODNAME: Types::CairoX::Sweet
-# ABSTRACT:
 library Types::CairoX::Sweet
 
 extends Types::Standard, Types::TypeTiny
@@ -111,11 +110,11 @@ __END__
 
 =head1 NAME
 
-Types::CairoX::Sweet - library Types::CairoX::Sweet
+Types::CairoX::Sweet
 
 =head1 VERSION
 
-Version 0.0102, released 2015-01-11.
+Version 0.0103, released 2015-01-11.
 
 =head1 SOURCE
 
